@@ -9,6 +9,11 @@
 
 import partialsmiles as ps
 
+# RDKit Imports
+# -------------
+
+from rdkit import Chem
+
 class PartialSmilesValidation(object):
 
     __version__ = '0.0.1'
@@ -20,7 +25,7 @@ class PartialSmilesValidation(object):
 
         self.partial = partial
 
-    def validate(self, smiles_list):
+    def validate(self, smiles_list, partial_smiles=True, rdkit=True):
 
         '''
 
@@ -35,14 +40,20 @@ class PartialSmilesValidation(object):
 
         '''
 
+
         successes = []
         failures = []
 
         for smiles in smiles_list:
             try:
-                mol = ps.ParseSmiles(smiles, partial=self.partial)
+                if partial_smiles:
+                    mol = ps.ParseSmiles(smiles, partial=self.partial)
+                if rdkit:
+                    mol = Chem.MolFromSmiles(smiles)
                 successes.append(smiles)
             except:
                 failures.append(smiles)
 
+
+
         return successes, failures
\ No newline at end of file
